package ch.zhaw.projekt2.turnierverwaltung;

import ch.zhaw.projekt2.turnierverwaltung.main.gameScheduleView.GameController;
import ch.zhaw.projekt2.turnierverwaltung.main.gameScheduleView.GameDecorator;
import javafx.fxml.FXMLLoader;
import javafx.geometry.Insets;
import javafx.scene.control.Label;
import javafx.scene.layout.*;
import javafx.scene.paint.Color;
import javafx.scene.text.Font;

import java.io.IOException;

public class Factory {
    private TournamentDecorator tournamentDecorator;
    private FileIO fileIO;

    public Factory(FileIO fileIO, TournamentDecorator tournamentDecorator) {
        this.fileIO = fileIO;
        this.tournamentDecorator = tournamentDecorator;

    }

    public TournamentDecorator getTournamentDecorator() {
        return tournamentDecorator;
    }

    public void setTournament(Tournament tournament) {
        this.tournamentDecorator.setTournament(tournament);
    }

    public BorderPane loadMainWindow() {
        FXMLLoader loader = new FXMLLoader(getClass().getResource("mainWindow.fxml"));
        try {
            return loader.load();
        } catch (IOException e) {
            e.printStackTrace();
            //TODO handle and logging
        }
        return null;
    }

    public void loadAllViews(FactoryDecorator factoryDecorator, BorderPane pane){
        for(View view : View.values()){
            try {
                view.loadView(tournamentDecorator, fileIO, factoryDecorator, pane);
            } catch (IOException e) {
                e.printStackTrace();
                //TODO Handle and logging.
            }
        }
    }

    public void showTournamentList(BorderPane pane, FactoryDecorator factoryDecorator) {
        tournamentDecorator.setTournament(null);
        setCenterOfBorderPane(pane, View.tournamentList);
    }

    //Can be used to Open new Scene in same Stage.
    //This way possible to later give object to Controller
    public void showParticipantFormular(BorderPane pane, FactoryDecorator factoryDecorator) {
        setCenterOfBorderPane(pane, View.participantFormular);
    }

    public void showPlacesFormular(BorderPane pane, FactoryDecorator factoryDecorator) {
        setCenterOfBorderPane(pane, View.placesFormular);
    }

    public void showGameScheduler(BorderPane pane, FactoryDecorator factoryDecorator) {
        setCenterOfBorderPane(pane, View.gameScheduler);
    }

    private void setCenterOfBorderPane(BorderPane pane, View view) {
        FXController controller = null;
        pane.setCenter(view.getPane());
        resetFooter(pane, true);
    }


    public GameController loadGameView(VBox box, GameDecorator gameDecorator, FactoryDecorator factoryDecorator) {
        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource("gameScheduleView/Game.fxml"));
            box.getChildren().add(loader.load());
            GameController controller = loader.getController();
            controller.setup(tournamentDecorator, fileIO, factoryDecorator, box, gameDecorator);
            return controller;
        } catch (IOException e) {
            e.printStackTrace();
            //TODO LOGGER
        }
        return null;
    }

    public void printMessageToFooter(BorderPane pane, String msg, boolean error) {
        VBox bottom = (VBox) pane.getBottom();
        Label label = new Label();
        VBox innerVbox;
        label.setText(msg);

        if (error) {
            innerVbox = (VBox) bottom.getChildren().get(0);
            resetFooter(pane, true);
            label.setTextFill(Color.RED);
            label.setFont(new Font(20));
            innerVbox.setBorder(new Border(new BorderStroke(Color.valueOf("#FF0000"), BorderStrokeStyle.SOLID, CornerRadii.EMPTY, BorderWidths.DEFAULT)));
            innerVbox.getChildren().add(label);

        } else {
            innerVbox = (VBox) bottom.getChildren().get(1);
            resetFooter(pane,false);
            label.setTextFill(Color.GREEN);
            label.setFont(new Font(10));
            label.setPadding(new Insets(0,10,0,0));
            innerVbox.getChildren().add(label);

        }


    }

    public void resetFooter(BorderPane pane,boolean error) {
        VBox bottom = (VBox) pane.getBottom();
        VBox vBox;
        if (error) {
            vBox = (VBox) bottom.getChildren().get(0);
        } else {
            vBox = (VBox) bottom.getChildren().get(1);
        }
        vBox.getChildren().clear();
        vBox.setBorder(null);
    }

    public enum View {
        tournamentList("tournamentList/tournamentList.fxml"),
        participantFormular("participantAddFormular/participantFormular.fxml"),
        placesFormular("placesAddFormular/PlacesFormular.fxml"),
        gameScheduler("gameScheduleView/GameSchedule.fxml");

        private String fxmlFileName;
        private Pane pane;

        private View(String fxmlFileName) {
            this.fxmlFileName = fxmlFileName;
        }

        public Pane getPane() {
            return pane;
        }

        public void loadView(TournamentDecorator tournamentDecorator, FileIO fileIO, FactoryDecorator factoryDecorator, BorderPane borderPane) throws IOException {
            FXMLLoader loader = new FXMLLoader(getClass().getResource(fxmlFileName));
            this.pane = loader.load();
            FXController controller = loader.getController();
            controller.setup(tournamentDecorator, fileIO, factoryDecorator, borderPane);
        }

    }

}
