package ch.zhaw.projekt2.turnierverwaltung;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;


/**
 * Class Team represents a team that can be added to a tournament
 * (in the prototype there is no functionality for the team)
 */
public class Team implements Participant {
    private String name;
    private List<Player> players;
    private Person contactPerson;

    private static final Logger logger = Logger.getLogger(FileIO.class.getCanonicalName());

    /**
     * Constructor to initiate a team, sets its name
     *
     * @param name the new name to be set
     */
    public Team(String name) {
        logger.fine("Setting the new  name of the team as: " + name);
        setName(name);
        players = new ArrayList<>();
    }

    /**
     * Method to add a new player to a team
     *
     * @param player new player to be added to a team
     */
    public void addPlayer(Player player) {
        logger.fine("Adding new Player named: " + player + "into the team");
        players.add(player);
    }

    /**
     * Method to return the name of the team
     *
     * @return the name of the team
     */
    @Override
    public String getName() {
        logger.fine("Returning the name of the team:" + name);
        return name;
    }

    /**
     * Method to set the name of a team
     *
     * @param name of the team
     */
    @Override
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Method that sets a complete List of all players as players of the team
     *
     * @param players List of Players to be set
     */
    public void setPlayers(List<Player> players) {
        logger.fine("Inserts Player");
        this.players = players;
    }

    /**
     * Method to get the List of all Players in a team
     *
     * @return List of all players in team
     */
    public List<Player> getPlayers() {
        logger.fine("Returning List of all players in " + getName());
        return players;
    }

    /**
     * Override of equals Method to compare teams with each other
     *
     * @param participant to be compared with this instance
     * @return true if teams are the same false if not.
     */
    @Override
    public boolean equals(Participant participant) {
        return getClass().equals(participant.getClass()) && toString().equalsIgnoreCase(participant.toString());
    }

    /**
     * Functionality to save a team is not implemented in this prototype, so no functionality is set yet to change the team
     *
     * @param participant date object containing new data
     */
    @Override
    public void change(Participant participant) {
    }

    /**
     * Method to get the current contact person of a team
     *
     * @return the current contact person
     */
    public Person getContactPerson() {
        logger.fine("Returning contact Person of team " + getName());
        return contactPerson;
    }

    /**
     * Method to set a Person as a contact person of a team
     *
     * @param contactPerson to be set
     */
    public void setContactPerson(Person contactPerson) {
        logger.fine("Setting " + contactPerson + " as a contact Person for team " + getName());
        this.contactPerson = contactPerson;
    }

    /**
     * Override of toString method, that returns the current name
     *
     * @return name in form of a String
     */
    @Override
    public String toString() {
        return name;
    }
}
